%global shortv %(echo %version|awk -F. '{print $1 "." $2}')
%global cubew_vers %version
%global shortwv %(echo %cubew_vers|awk -F. '{print $1 "." $2}')
%{!?bash_completion_dir:%global bash_completion_dir /usr/share/bash-completion/comlpetions}
%global intver 12:0:2

Name:           cube
Version:        4.8.1
Release:    1%{?dist}
Summary:        CUBE Uniform Behavioral Encoding generic presentation component
License:        BSD-3-Clause
URL:            http://www.scalasca.org/software/cube-4.x/download.html
Source0:        http://apps.fz-juelich.de/scalasca/releases/cube/%shortwv/dist/cubegui-%{version}.tar.gz
Source1:        http://apps.fz-juelich.de/scalasca/releases/cube/%shortwv/dist/cubew-%{cubew_vers}.tar.gz
Source2:        http://apps.fz-juelich.de/scalasca/releases/cube/%shortwv/dist/cubelib-%{version}.tar.gz
%if 0
Source0:        https://perftools.pages.jsc.fz-juelich.de/cicd/cubegui/tags/cubegui-4.8-rc1/cubegui-4.8-rc1.tar.gz
Source1:        https://perftools.pages.jsc.fz-juelich.de/cicd/cubew/tags/cubew-4.8-rc1/cubew-4.8-rc1.tar.gz
Source2:        https://perftools.pages.jsc.fz-juelich.de/cicd/cubelib/tags/cubelib-4.8-rc1/cubelib-4.8-rc1.tar.gz
%endif
Patch1:         cube-configure-c99.patch
BuildRequires:  dbus-devel
BuildRequires:  qt5-qtbase-devel
BuildRequires:  chrpath
BuildRequires:  desktop-file-utils
BuildRequires:  zlib-devel
BuildRequires: 	make
BuildRequires:  %{?dts:%dts-}gcc-c++
%ifarch %qt5_qtwebengine_arches
BuildRequires:  qt5-qtwebengine-devel
%endif
Requires:       %{name}-libs = %{version}-%{release}

%global ver %version

%description
CUBE (CUBE Uniform Behavioral Encoding) is a generic presentation component
suitable for displaying a wide variety of performance metrics for parallel
programs including MPI and OpenMP applications. CUBE allows interactive
exploration of a multidimensional performance space in a scalable fashion.
Scalability is achieved in two ways: hierarchical decomposition of individual
dimensions and aggregation across different dimensions. All performance
metrics are uniformly accommodated in the same display and thus provide the
ability to easily compare the effects of different kinds of performance
behavior.


%package        libs
Summary:        Non-GUI libraries for %{name}

%description    libs
Non-GUI libraries required by %{name}

%package  	libs-devel
Summary:	Development files for %{name}-libs
Requires:       %{name}-libs = %{version}-%{release}

%description	libs-devel
Development files for %{name}-libs.

%package        guilib
Summary:        GUI library for %{name}

%description    guilib
GUI library for %{name}.

%package  	guilib-devel
Summary:	Development files for %{name}-guilib
Requires:       %{name}-guilib = %{version}-%{release}

%description	guilib-devel
Development files for %{name}-guilib.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs-devel = %{version}-%{release}
Requires:	%{name}-guilib-devel = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}, including GUI applications.


%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation for %{name}.


%prep
%setup -q -c
tar fx %SOURCE0
tar fx %SOURCE1
tar fx %SOURCE2
%patch1 -p1
cat <<+ >cubelib-config
case \$1 in
--cppflags|--cflags) printf '%s\n' -I$(pwd)/cubelib-%ver/inst%_includedir/cubelib ;;
--ldflags)  printf '%s\n' -L$(pwd)/cubelib-%ver/inst%_libdir ;;
--libs) printf '%s\n' '-lcube4 -lz' ;;
--interface-version) printf '%s\n' %intver ;;
esac
+
chmod +x cubelib-config
for d in cubew-* cubelib-%ver cubegui-*; do
  printf 'CC=gcc\nCXX=g++\n' >$d/build-config/common/platforms/platform-backend-linux
done


%build
%{?dts:. /opt/rh/%dts/enable}
%global unhardcode \
  sed -i -e 's/HARDCODE_INTO_LIBS"]="1"/HARDCODE_INTO_LIBS"]="0"/' \\\
         -e "s/hardcode_into_libs='yes'/hardcode_into_libs='no'/"
cd cubew-%cubew_vers
%configure --enable-shared --disable-static --disable-silent-rules \
   CXXFLAGS="$CXXFLAGS" CFLAGS="$CFLAGS" LDFLAGS="$LDFLAGS"
%unhardcode build-backend/config.status
%make_build
cd ../cubelib-%ver
%configure --enable-shared --disable-static --disable-silent-rules \
   CXXFLAGS="$CXXFLAGS" CFLAGS="$CFLAGS" LDFLAGS="$LDFLAGS"
%unhardcode build-frontend/config.status
%make_build
make install DESTDIR=$(pwd)/inst
rm inst%_libdir/*.la
cd ../cubegui-%ver
export LIBS="$LIBS -lQt5PrintSupport -lQt5Widgets -lQt5Gui -lQt5Network -lQt5Concurrent -lQt5Core"
%configure --disable-static \
  --disable-silent-rules \
  --with-platform=linux \
  --with-cubelib=$(pwd)/.. \
   CXXFLAGS="$CXXFLAGS" CFLAGS="$CFLAGS" LDFLAGS="$LDFLAGS"
%unhardcode build-frontend/config.status
%make_build


%install
%make_install -C cubew-%cubew_vers
%make_install -C cubelib-%ver
%make_install -C cubegui-%ver
find %{buildroot} -name '*.la' -exec rm -f {} ';'

ln -sf ../../cubelib/example/{trace,summary}.cubex %buildroot%_docdir/cubegui/example

mkdir -p %{buildroot}%{_datadir}/appdata
cat > %{buildroot}%{_datadir}/appdata/CUBE.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2014 Forschungszentrum Juelich GmbH, Germany -->

<application>
 <id type="desktop">CUBE.desktop</id>
 <metadata_license>CC0-1.0</metadata_license>
 <project_license>BSD-3-Clause</project_license>
 <name>Cube</name>
 <summary>A presentation component suitable for displaying
performance data for parallel programs</summary>
 <description>
  <p>
    "Cube" (CUBE Uniform Behavioral Encoding) is a presentation
    component suitable for displaying a wide variety of performance
    data for parallel programs including MPI and OpenMP applications.
  </p>
  <p>
    Program performance is represented in a multi-dimensional space including various program and
    system resources. The tool allows the interactive exploration of this
    space in a scalable fashion and browsing the different kinds of
    performance behavior with ease.  All metrics are uniformly accommodated in the 
    same display and thus provide the ability to easily compare the effects of 
    different kinds of program behavior.
  </p>
  <p>
    "Cube" also includes a library to
    read and write performance data as well as operators to compare,
    integrate, and summarize data from different experiments. 
  </p>
  <p>
    The Cube 4.x release series uses an incompatible API and
    file format compared to previous versions, however,
    existing files in CUBE3 format can still be processed
    for backwards-compatibility.    
  </p>
 </description>
 <screenshots>
  <screenshot type="default" width="1152" height="648">http://apps.fz-juelich.de/scalasca/releases/cube/screenshots/topo1.png</screenshot>
  <screenshot width="1152" height="648">http://apps.fz-juelich.de/scalasca/releases/cube/screenshots/topo2.png</screenshot>
  <screenshot width="1152" height="648">http://apps.fz-juelich.de/scalasca/releases/cube/screenshots/box.png</screenshot>
  <screenshot width="1152" height="648">http://apps.fz-juelich.de/scalasca/releases/cube/screenshots/flat.png</screenshot>
  <screenshot width="1152" height="648">http://apps.fz-juelich.de/scalasca/releases/cube/screenshots/palette.png</screenshot>
 </screenshots>
 <url type="homepage">http://www.scalasca.org/software/cube-4.x/download.html</url>
 <updatecontact>scalasca_at_fz-juelich.de</updatecontact>
</application>
EOF

chrpath -d -k %{buildroot}%{_bindir}/* %{buildroot}%{_libdir}/{,cube-plugins/}*.so  || :

cat <<EOF >CUBE.desktop
[Desktop Entry]
Comment=Performance profile browser CUBE
Exec=%_bindir/cube
Icon=%_datadir/icons/cubegui/Cube.xpm
InitialPreference=3
MimeType=application/cube;
Name=Cube (scalasca.org)
Terminal=false
Type=Application
Categories=Science;ComputerScience;DataVisualization;
EOF
desktop-file-install --dir=%{buildroot}%{_datadir}/applications CUBE.desktop

cat >%{buildroot}%{_libdir}/cube-plugins/plugins.abignore <<EOF
[suppress_file]
file_name_regexp = .*-plugin\\.so.*
EOF

mkdir -p %{buildroot}%{bash_completion_dir}
mv %{buildroot}%{_bindir}/cubegui-autocompletion.sh %{buildroot}%{bash_completion_dir}/cubegui
rm %{buildroot}%{_bindir}/maccubegui.sh


%check
%{?dts:. /opt/rh/%dts/enable}
make -C cubelib-%ver check || { cat test/test*/*log && false; }
make -C cubew-%cubew_vers check || { cat test/test*/*log && false; }




%files
%license cubegui-%ver/COPYING
%doc cubegui-%ver/AUTHORS
%doc cubegui-%ver/ChangeLog
%doc cubegui-%ver/OPEN_ISSUES
%doc cubegui-%ver/README
%{_bindir}/cube
%{_bindir}/cube3to4
%{_bindir}/cube4to3
%{_bindir}/cube_calltree
%{_bindir}/cube_canonize
%{_bindir}/cube_clean
%{_bindir}/cube_cmp
%{_bindir}/cube_commoncalltree
%{_bindir}/cube_cut
%{_bindir}/cube_derive
%{_bindir}/cube_diff
%{_bindir}/cube_dump
%{_bindir}/cube_exclusify
%{_bindir}/cube_inclusify
%{_bindir}/cube_info
%{_bindir}/cube_is_empty
%{_bindir}/cube_mean
%{_bindir}/cube_merge
%{_bindir}/cube_nodeview
%{_bindir}/cube_part
%{_bindir}/cube_rank
%{_bindir}/cube_regioninfo
%{_bindir}/cube_remap2
%{_bindir}/cube_sanity
%{_bindir}/cube_stat
%{_bindir}/cube_test
%{_bindir}/cube_topoassist
%{_bindir}/tau2cube
%{_libdir}/libgraphwidgetcommon-plugin.so.10*
%{_libdir}/cube-plugins/
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/applications/CUBE.desktop
%{_datadir}/icons/*
%{_datadir}/cubegui/
%{bash_completion_dir}/cubegui

%files devel

%files libs
%license cubegui-%ver/COPYING
%{_bindir}/cube_server
%exclude %{_libdir}/lib%{name}4gui*.so*
%{_libdir}/lib%{name}*.so.12*
%{_datadir}/cubelib/
%{_datadir}/cubew/

%files libs-devel
%{_bindir}/cubelib-config
%{_bindir}/cubew-config
%{_includedir}/cubew
%{_includedir}/cubelib
%{_libdir}/lib%{name}*.so
%doc cubegui-%ver/examples

%files guilib
%license cubegui-%ver/COPYING
%{_libdir}/lib%{name}4gui.so.10*
%{_libdir}/libgraphwidgetcommon-plugin.so

%files guilib-devel
%{_bindir}/cubegui-config
%{_includedir}/cubegui
%{_libdir}/lib%{name}4gui.so

%files doc
%license cubegui-%ver/COPYING
%doc %_docdir/cubew
%doc %_docdir/cubelib
%doc %_docdir/cubegui


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.8.1-1
- initial build
